@@ -1,6 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2003, 2005, 2007, 2009-2012, 2014-2015 Free
-   Software Foundation, Inc.
+   Copyright (C) 1999-2019 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -216,7 +215,7 @@ mime_descend (struct mime_descend_closure *closure,
 	    }
 	}
     }
-  else if (mu_c_strncasecmp (type, "message/rfc822", strlen (type)) == 0)
+  else if (mu_c_strncasecmp (type, "message/rfc822", 14) == 0)
     {
       mu_message_t submsg = NULL;
 
@@ -245,7 +244,7 @@ display_submessage (struct mime_descend_closure *closure, void *data)
 {
   char *tmp;
   
-  if (mailvar_get (&tmp, "metamail", mailvar_type_string, 0) == 0)
+  if (mailvar_get (&tmp, mailvar_name_metamail, mailvar_type_string, 0) == 0)
     {
       /* If `metamail' is set to a string, treat it as command line
 	 of external metamail program. */
@@ -281,18 +280,14 @@ display_submessage (struct mime_descend_closure *closure, void *data)
       
       /* If `metamail' is set to true, enable internal mailcap
 	 support */
-      if (mailvar_get (NULL, "metamail", mailvar_type_boolean, 0) == 0)
+      if (mailvar_is_true (mailvar_name_metamail))
 	{
 	  char *no_ask = NULL;
-	  int debug = 0;
-	  
-	  mailvar_get (&no_ask, "mimenoask", mailvar_type_string, 0);
-	  if (mailvar_get (&debug, "verbose", mailvar_type_boolean, 0) == 0
-	      && debug)
-	    debug = 9;
 	  
+	  mailvar_get (&no_ask, mailvar_name_mimenoask, mailvar_type_string, 0);
 	  builtin_display = display_stream_mailcap (NULL, stream, hdr, no_ask,
-						    interactive, 0, debug);
+						    interactive, 0,
+						    MU_DEBCAT_APP);
 	}
       
       if (builtin_display)
@@ -405,13 +400,14 @@ run_metamail (const char *mailcap_cmd, mu_message_t mesg)
 	  char *no_ask;
 	  
 	  setenv ("METAMAIL_PAGER", getenv ("PAGER"), 0);
-	  if (mailvar_get (&no_ask, "mimenoask", mailvar_type_string, 0))
+	  if (mailvar_get (&no_ask, mailvar_name_mimenoask,
+			   mailvar_type_string, 0))
 	    setenv ("MM_NOASK", no_ask, 1);
 	  
 	  status = mu_message_get_streamref (mesg, &stream);
 	  if (status)
 	    {
-	      mu_error ("mu_message_get_stream: %s", mu_strerror (status));
+	      mu_error ("mu_message_get_streamref: %s", mu_strerror (status));
 	      break;
 	    }
 
