@@ -1,6 +1,5 @@
 /* GNU Mailutils -- a suite of utilities for electronic mail
-   Copyright (C) 1999-2002, 2005-2007, 2009-2012, 2014-2018 Free
-   Software Foundation, Inc.
+   Copyright (C) 1999-2019 Free Software Foundation, Inc.
 
    GNU Mailutils is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -133,7 +132,7 @@ struct mail_escape_entry
   const char *synopsis;
   int (*escfunc) (int, char **, compose_env_t *);
 };
-
+
 enum mailvar_type
   {
     mailvar_type_whatever,
@@ -157,6 +156,81 @@ struct mailvar_variable
   union mailvar_value value;
 };
 
+/* Internal variable names */
+#define mailvar_name_allnet                     "allnet"
+#define mailvar_name_append                     "append"
+#define mailvar_name_appenddeadletter           "appenddeadletter"
+#define mailvar_name_askbcc                     "askbcc"
+#define mailvar_name_askcc                      "askcc"
+#define mailvar_name_ask                        "ask"
+#define mailvar_name_asksub                     "asksub"
+#define mailvar_name_autoinc                    "autoinc"
+#define mailvar_name_autoprint                  "autoprint"
+#define mailvar_name_byname                     "byname"
+#define mailvar_name_bang                       "bang"
+#define mailvar_name_charset                    "charset"
+#define mailvar_name_cmd                        "cmd"
+#define mailvar_name_columns                    "columns"
+#define mailvar_name_crt                        "crt"
+#define mailvar_name_datefield                  "datefield"
+#define mailvar_name_debug                      "debug"
+#define mailvar_name_decode_fallback            "decode-fallback"
+#define mailvar_name_dot                        "dot"
+#define mailvar_name_editheaders                "editheaders"
+#define mailvar_name_emptystart                 "emptystart"
+#define mailvar_name_escape                     "escape"
+#define mailvar_name_flipr                      "flipr"
+#define mailvar_name_folder                     "folder"
+#define mailvar_name_fromfield                  "fromfield"
+#define mailvar_name_gnu_last_command           "gnu-last-command"
+#define mailvar_name_header                     "header"
+#define mailvar_name_headline                   "headline"
+#define mailvar_name_hold                       "hold"
+#define mailvar_name_ignore                     "ignore"
+#define mailvar_name_ignoreeof                  "ignoreeof"
+#define mailvar_name_indentprefix               "indentprefix"
+#define mailvar_name_inplacealiases             "inplacealiases"
+#define mailvar_name_keep                       "keep"
+#define mailvar_name_keepsave                   "keepsave"
+#define mailvar_name_mailx                      "mailx"
+#define mailvar_name_metamail                   "metamail"
+#define mailvar_name_metoo                      "metoo"
+#define mailvar_name_mimenoask                  "mimenoask"
+#define mailvar_name_mode                       "mode"
+#define mailvar_name_nullbody                   "nullbody"
+#define mailvar_name_nullbodymsg                "nullbodymsg"
+#define mailvar_name_outfolder                  "outfolder"
+#define mailvar_name_page                       "page"
+#define mailvar_name_prompt                     "prompt"
+#define mailvar_name_quit                       "quit"
+#define mailvar_name_rc                         "rc"
+#define mailvar_name_readonly                   "readonly"
+#define mailvar_name_record                     "record"
+#define mailvar_name_recursivealiases           "recursivealiases"
+#define mailvar_name_regex                      "regex"
+#define mailvar_name_replyprefix                "replyprefix"
+#define mailvar_name_replyregex                 "replyregex"
+#define mailvar_name_return_address             "return-address"
+#define mailvar_name_save                       "save"
+#define mailvar_name_screen                     "screen"
+#define mailvar_name_sendmail                   "sendmail"
+#define mailvar_name_sendwait                   "sendwait"
+#define mailvar_name_sign                       "sign"
+#define mailvar_name_Sign                       "Sign"
+#define mailvar_name_showenvelope               "showenvelope"
+#define mailvar_name_showto                     "showto"
+#define mailvar_name_toplines                   "toplines"
+#define mailvar_name_variable_pretty_print      "variable-pretty-print"
+#define mailvar_name_varpp                      "varpp"
+#define mailvar_name_variable_strict            "variable-strict"
+#define mailvar_name_varstrict                  "varstrict"
+#define mailvar_name_verbose                    "verbose"
+#define mailvar_name_xmailer                    "xmailer"
+#define mailvar_name_mime                       "mime"
+#define mailvar_name_onehop                     "onehop"
+#define mailvar_name_quiet                      "quiet"
+#define mailvar_name_PID                        "PID"  
+
 typedef struct message_set msgset_t;
 
 struct message_set
@@ -173,6 +247,7 @@ typedef int (*msg_handler_t) (msgset_t *mp, mu_message_t mesg, void *data);
 extern mu_mailbox_t mbox;
 extern size_t total;
 extern int interactive;
+extern mu_url_t secondary_url;
 extern const char *program_version;
 extern char *default_encoding;
 extern char *default_content_type;
@@ -240,7 +315,8 @@ int mail_z (int argc, char **argv);
 int mail_eq (int argc, char **argv);	/* command = */
 int mail_setenv (int argc, char **argv);
 int mail_envelope (int argc, char **argv);
-int print_envelope (msgset_t *mspec, mu_message_t msg, void *data);
+int print_stream_envelope (mu_stream_t str, msgset_t *mspec, mu_message_t msg,
+			   char const *pfx);
 int mail_struct (int argc, char **argv);
 
 int if_cond (void);
@@ -259,7 +335,7 @@ char *mail_whoami (void);
 int mail_header_is_visible (const char *str);
 int mail_header_is_unfoldable (const char *str);
 int mail_mbox_close (void);
-char *mail_expand_name (const char *name);
+int mail_expand_name (const char *name, mu_url_t *purl);
 
 void send_append_header (char const *text);
 void send_append_header2 (char const *name, char const *value, int mode);
@@ -318,6 +394,7 @@ int is_current_message (size_t n);
 void msgset_free (msgset_t *msg_set);
 msgset_t *msgset_make_1 (size_t number);
 msgset_t *msgset_append (msgset_t *one, msgset_t *two);
+void msgset_remove (msgset_t **pset, size_t n);
 msgset_t *msgset_range (int low, int high);
 msgset_t *msgset_expand (msgset_t *set, msgset_t *expand_by);
 msgset_t *msgset_dup (const msgset_t *set);
@@ -428,6 +505,7 @@ const char *util_url_to_string (mu_url_t url);
 mu_stream_t open_pager (size_t lines);
 
 void format_msgset (mu_stream_t str, const msgset_t *msgset, size_t *count);
+char *sender_string (mu_message_t msg);
 
 int is_address_field (const char *name);
 
@@ -480,6 +558,16 @@ char *readline (char *prompt);
 #define MAIL_ATTRIBUTE_TOUCHED  0x0020
 
 void ml_attempted_completion_over (void);
+void ml_set_completion_append_character (int);
+
+/* Flags for per-command completion functions */
+enum
+  {
+    COMPL_DFL     = 0x0, /* Nothing special */
+    COMPL_WS      = 0x1, /* Cursor pointing to a whitespace character
+			    at the start of input or past another whitespace */
+    COMPL_LASTARG = 0x2  /* Cursor pointing at or past the last argument */
+  };
 
 #ifdef WITH_READLINE
 char **file_compl (int argc, char **argv, int ws);
@@ -491,6 +579,7 @@ char **command_compl (int argc, char **argv, int ws);
 char **alias_compl (int argc, char **argv, int ws);
 char **mailvar_set_compl (int argc, char **argv, int ws);
 char **exec_compl (int argc, char **argv, int ws);
+char **shell_compl (int argc, char **argv, int ws);
 #else
 # define file_compl NULL
 # define no_compl NULL
@@ -501,6 +590,7 @@ char **exec_compl (int argc, char **argv, int ws);
 # define alias_compl NULL
 # define var_compl NULL
 # define exec_compl NULL     
+# define shell_compl NULL
 # define mailvar_set_compl NULL
 #endif
 
